// Blue Moon Linux
// Creator: Antonius32
// Version 2.0

/**
 * @fileOverview User Stylesheet module
 * @author       wantora
 * @version      1.0.0
 *
 * @license
 *   The MIT License.
 *   Copyright (c) 2011 wantora
 *   
 *   Permission is hereby granted, free of charge, to any person obtaining a copy
 *   of this software and associated documentation files (the "Software"), to deal
 *   in the Software without restriction, including without limitation the rights
 *   to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *   copies of the Software, and to permit persons to whom the Software is
 *   furnished to do so, subject to the following conditions:
 *   
 *   The above copyright notice and this permission notice shall be included in
 *   all copies or substantial portions of the Software.
 *   
 *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 *   THE SOFTWARE.
 * @url https://bitbucket.org/wantora/
 */

const EXPORTED_SYMBOLS = ["UserStylesheet"];

var SSService = Cc["@mozilla.org/content/style-sheet-service;1"].getService(Ci.nsIStyleSheetService);
var IOService = Cc["@mozilla.org/network/io-service;1"].getService(Ci.nsIIOService);

var Instances = [];

function UserStylesheet(cssurl) {
	this._cssurl = IOService.newURI(cssurl, null, null);
	
	Instances.push(this);
}
UserStylesheet.prototype.register = function(){
	SSService.loadAndRegisterSheet(this._cssurl, SSService.USER_SHEET);
};
UserStylesheet.prototype.unregister = function(){
	if (SSService.sheetRegistered(this._cssurl, SSService.USER_SHEET)) {
		SSService.unregisterSheet(this._cssurl, SSService.USER_SHEET);
	}
};
UserStylesheet.prototype.destroy = function(){
	if (this._cssurl) {
		this.unregister();
	}
	
	delete this._cssurl;
	
	var index = Instances.indexOf(this);
	if (index >= 0) Instances.splice(index, 1);
};


/** A handler for bootstrap.js */
function shutdown()
{
	Instances.forEach(function(ss){
		ss.destroy();
	});
	StyleSheetService = null;
	IOService = null;
	Instances = null;
}
